var searchData=
[
  ['equation_20program_0',['The heat-equation program',['../heat_equation.html',1,'']]],
  ['example_1',['Example',['../group__Executor.html#autotoc_md72',1,'Example'],['../group__Executor.html#autotoc_md73',1,'Example']]],
  ['example_20programs_2',['Example programs',['../Examples.html',1,'']]],
  ['example_3a_20permuting_20a_20csr_20matrix_3a_3',['Example: Permuting a Csr matrix:',['../classgko_1_1Permutable.html#autotoc_md76',1,'']]],
  ['example_3a_20transposing_20a_20csr_20matrix_3a_4',['Example: Transposing a Csr matrix:',['../classgko_1_1Transposable.html#autotoc_md75',1,'']]],
  ['example_3a_20using_20batchcg_20in_20ginkgo_5',['Example: using BatchCG in Ginkgo',['../classgko_1_1batch_1_1BatchLinOpFactory.html#autotoc_md71',1,'']]],
  ['example_3a_20using_20cg_20in_20ginkgo_6',['Example: using CG in Ginkgo',['../classgko_1_1LinOpFactory.html#autotoc_md74',1,'']]],
  ['examples_7',['Examples',['../classgko_1_1range.html#autotoc_md80',1,'']]],
  ['examples_8',['Documenting examples',['../contributing_guidelines.html#autotoc_md62',1,'']]],
  ['executors_20in_20ginkgo_9',['Executors in Ginkgo.',['../group__Executor.html#exec_1',1,'']]],
  ['export_20program_10',['The preconditioner-export program',['../preconditioner_export.html',1,'']]],
  ['extended_20header_20files_11',['Extended header files',['../contributing_guidelines.html#autotoc_md21',1,'']]]
];
